@@ -2,5 +2,5 @@ from .sleep import SleepFeeder, SleepDownloader
 from .random import RandomFeeder, RandomFilterFeeder, RandomFilterDownloader
 from .just import JustDownloader, JustLogCallbackDownloader
 from .subprocess import SubprocessDownloader
-from .exception import ExceptionFeederFilter, ExceptionDownloaderFilter, ExceptionDownloaderCallback
-from .exception import ExceptionDownloaderFilterCallback
+from .exception import ExceptionFilterFeeder, ExceptionFilterDownloader, ExceptionCallbackDownloader
+from .exception import ExceptionFilterCallbackDownloader
